from tfitpy.indices.grn import GRN_METHODS
from tfitpy.indices.ppi import PPI_METHODS
from tfitpy.indices.go import GO_METHODS


METHODS = {
  ** PPI_METHODS,
  ** GO_METHODS,
  ** GRN_METHODS
}

def list():
  """
  List all indices available
  """